# aiohomeconnect

<p align="center">
  <a href="https://github.com/MartinHjelmare/aiohomeconnect/actions/workflows/ci.yml?query=branch%3Amain">
    <img src="https://img.shields.io/github/actions/workflow/status/MartinHjelmare/aiohomeconnect/ci.yml?branch=main&label=CI&logo=github&style=flat-square" alt="CI Status" >
  </a>
  <a href="https://aiohomeconnect.readthedocs.io">
    <img src="https://img.shields.io/readthedocs/aiohomeconnect.svg?logo=read-the-docs&logoColor=fff&style=flat-square" alt="Documentation Status">
  </a>
  <a href="https://codecov.io/gh/MartinHjelmare/aiohomeconnect">
    <img src="https://img.shields.io/codecov/c/github/MartinHjelmare/aiohomeconnect.svg?logo=codecov&logoColor=fff&style=flat-square" alt="Test coverage percentage">
  </a>
</p>
<p align="center">
  <a href="https://python-poetry.org/">
    <img src="https://img.shields.io/endpoint?url=https://python-poetry.org/badge/v0.json" alt="Poetry">
  </a>
  <a href="https://github.com/astral-sh/ruff">
    <img src="https://img.shields.io/endpoint?url=https://raw.githubusercontent.com/astral-sh/ruff/main/assets/badge/v2.json" alt="Ruff">
  </a>
  <a href="https://github.com/pre-commit/pre-commit">
    <img src="https://img.shields.io/badge/pre--commit-enabled-brightgreen?logo=pre-commit&logoColor=white&style=flat-square" alt="pre-commit">
  </a>
</p>
<p align="center">
  <a href="https://pypi.org/project/aiohomeconnect/">
    <img src="https://img.shields.io/pypi/v/aiohomeconnect.svg?logo=python&logoColor=fff&style=flat-square" alt="PyPI Version">
  </a>
  <img src="https://img.shields.io/pypi/pyversions/aiohomeconnect.svg?style=flat-square&logo=python&amp;logoColor=fff" alt="Supported Python versions">
  <img src="https://img.shields.io/pypi/l/aiohomeconnect.svg?style=flat-square" alt="License">
</p>

---

**Documentation**: <a href="https://aiohomeconnect.readthedocs.io" target="_blank">https://aiohomeconnect.readthedocs.io </a>

**Source Code**: <a href="https://github.com/MartinHjelmare/aiohomeconnect" target="_blank">https://github.com/MartinHjelmare/aiohomeconnect </a>

---

An asyncio client for the Home Connect API.

## Installation

Install this via pip (or your favourite package manager):

`pip install aiohomeconnect`

## Credits

This package was created with
[Copier](https://copier.readthedocs.io/) and the
[browniebroke/pypackage-template](https://github.com/browniebroke/pypackage-template)
project template.
